# Flask Toolkits
<!-- [![Downloads](https://static.pepy.tech/personalized-badge/flask-http-middleware?period=month&units=international_system&left_color=black&right_color=green&left_text=Downloads)](https://pepy.tech/project/flask-http-middleware) -->

## Repository
- [ ] [GITHUB](https://github.com/Danangjoyoo/flask-toolkits)

## Installation
```
pip install flask-toolkits
```

## Description
Flask toolkits implements and provides several features from FastAPI like:
- automatic API documentation using `AutoSwagger` (define the function and we'll generate the openapi spec for you)
- Base HTTP Middleware (middleware with direct access to `request` and `response`)
- pydantic's validator
- Response functions that could return any type of data without worried to get error
- much more..


## Changelogs
- v0.0
    - First Upload